@@ -8,7 +8,6 @@
 #include "utils_p.h"
 #include <KCalendarCore/Incidence>
 #include "akonadicalendar_debug.h"
-#include <item.h>
 #include <itemcreatejob.h>
 #include <collectionfetchjob.h>
 #include <collectionfetchscope.h>
@@ -210,7 +209,7 @@ void IncidenceChanger::Private::step2CreateIncidence(const Change::Ptr &change,
 
     mLastCollectionUsed = collection;
 
-    ItemCreateJob *createJob = new ItemCreateJob(change->newItem, collection, parentJob(change));
+    auto *createJob = new ItemCreateJob(change->newItem, collection, parentJob(change));
     mChangeForJob.insert(createJob, change);
 
     if (mBatchOperationInProgress) {
